# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['karaage',
 'karaage.common',
 'karaage.common.views',
 'karaage.conf',
 'karaage.datastores',
 'karaage.emails',
 'karaage.institutes',
 'karaage.machines',
 'karaage.machines.urls',
 'karaage.machines.views',
 'karaage.management',
 'karaage.management.commands',
 'karaage.middleware',
 'karaage.migrations',
 'karaage.people',
 'karaage.people.urls',
 'karaage.people.views',
 'karaage.plugins',
 'karaage.plugins.kgapplications',
 'karaage.plugins.kgapplications.conf',
 'karaage.plugins.kgapplications.management',
 'karaage.plugins.kgapplications.management.commands',
 'karaage.plugins.kgapplications.migrations',
 'karaage.plugins.kgapplications.templatetags',
 'karaage.plugins.kgapplications.tests',
 'karaage.plugins.kgapplications.views',
 'karaage.plugins.kgsoftware',
 'karaage.plugins.kgsoftware.applications',
 'karaage.plugins.kgsoftware.applications.migrations',
 'karaage.plugins.kgsoftware.applications.tests',
 'karaage.plugins.kgsoftware.conf',
 'karaage.plugins.kgsoftware.migrations',
 'karaage.plugins.kgsoftware.templatetags',
 'karaage.plugins.kgsoftware.tests',
 'karaage.projects',
 'karaage.templatetags',
 'karaage.tests',
 'karaage.tests.common',
 'karaage.tests.datastores',
 'karaage.tests.institutes',
 'karaage.tests.machines',
 'karaage.tests.people',
 'karaage.tests.projects']

package_data = \
{'': ['*'],
 'karaage': ['fixtures/*',
             'static/css/*',
             'static/css/images/*',
             'static/css/local/*',
             'static/img/*',
             'static/js/*',
             'templates/*',
             'templates/django_tables2/*',
             'templates/formfield/*',
             'templates/karaage/common/*',
             'templates/karaage/emails/*',
             'templates/karaage/institutes/*',
             'templates/karaage/machines/*',
             'templates/karaage/people/*',
             'templates/karaage/people/emails/*',
             'templates/karaage/projects/*'],
 'karaage.plugins.kgapplications': ['fixtures/*',
                                    'templates/kgapplications/*',
                                    'templates/kgapplications/emails/*'],
 'karaage.plugins.kgsoftware': ['fixtures/*', 'templates/kgsoftware/*'],
 'karaage.plugins.kgsoftware.applications': ['templates/kgapplications/*']}

install_requires = \
['Django>=4.1.2,<4.3.0',
 'bcrypt',
 'cracklib',
 'cssmin',
 'django-ajax-selects',
 'django-environ',
 'django-filter',
 'django-simple-captcha',
 'django-tables2',
 'django-tracking-model>=0.1.5,<0.2.0',
 'gunicorn',
 'jsmin>=3.0.1,<4.0.0',
 'ldap3',
 'mysqlclient',
 'psycopg2-binary',
 'pyjwt',
 'python-alogger',
 'python-tldap',
 'sentry-sdk',
 'six',
 'whitenoise']

extras_require = \
{'docs': ['sphinx', 'furo']}

setup_kwargs = {
    'name': 'karaage',
    'version': '6.2.3',
    'description': 'Web application to manage a HP cluster',
    'long_description': 'Karaage 3\n=========\n\n**Cluster account management tool.**\n\n.. contents :: Table of Contents\n\n\nWhat is Karaage?\n----------------\nKaraage is a cluster account management tool. It can manage users and projects\nin a cluster and can store the data in various backends.\n\n\nFeatures\n--------\n* Can store user information and/or posix account information in LDAP/Active Directory/passwd file.\n* Email notifications.\n* Auto account creation - Allow project leaders to manage their users.\n* Applications work flow - Users can apply for accounts and be approved by project leaders.\n* Usage reporting. Report on a per institute, per project or per user for CPU usage.\n* Track usage of software and versions. Keep track of what software (and version) and type of jobs a user is running.\n\n\nDocumentation\n-------------\n\n- `Karaage 3.x User documentation\n  <https://karaage.readthedocs.org/projects/karaage-user/en/latest/>`_\n\n- `Karaage 3.x Programmer documentation:\n  <https://karaage.readthedocs.org/projects/karaage-programmer/en/latest/>`_\n\n- `Karaage 3.x Admin documentation: <https://karaage.readthedocs.org/en/latest/>`_\n\n\nComponents\n----------\n\nKaraage is a complicated application and has more then one source repository:\n\n- `Karaage 3 karaage-cluster-tools\n  <https://github.com/Karaage-Cluster/karaage-cluster-tools>`_\n- `TLDAP library\n  <https://github.com/Karaage-Cluster/python-tldap>`_\n- `ALogger library\n  <https://github.com/Karaage-Cluster/python-alogger>`_\n- `Website\n  <https://github.com/Karaage-Cluster/Karaage-Cluster.github.io>`_\n- `Slurm Docker packaging\n  <https://github.com/Karaage-Cluster/slurm>`_\n\nAnything else not in this list has not been touched in years, and may not\nbe still relevant.\n\n\nPlugins\n-------\n\n* karaage-usage: The karaage-usage plugin provides monitoring of usage\n  information.\n* karaage-applications: This plugin allows users to self register accounts with\n  Karaage.\n* karaage-software: Keep track of installed software applications.\n\n\nSupport\n-------\n\n* `Mailing list <https://groups.google.com/d/forum/karaage-users>`_\n* `Bug reports <https://github.com/Karaage-Cluster/karaage/issues>`_\n\n\nSource code\n-----------\nKaraage is open source code and available under the GPL3 license.  You can find\nthe source code for Karaage at `github <https://github.com/Karaage-Cluster/karaage/>`_.\n',
    'author': 'Brian May',
    'author_email': 'brian@linuxpenguins.xyz',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Karaage-Cluster/django/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
